@@ -69,6 +69,8 @@ public:
 
     sigc::signal<void>& detached_from_target_signal () const;
 
+    sigc::signal<void>& inferior_re_run_signal () const;
+
     sigc::signal<void, const map<int, IDebugger::Breakpoint>&, const UString&>&
                                             breakpoints_list_signal () const;
 
@@ -290,7 +292,9 @@ public:
                        const vector<UString> &a_argv,
                        const UString &working_dir,
                        const vector<UString> &a_source_search_dirs,
-                       const UString &a_tty_path,
+                       const UString &a_slave_tty_path,
+		       int a_slave_tty_fd,
+		       bool a_uses_launch_tty,
 		       bool a_force);
 
     void load_core_file (const UString &a_prog_file,
@@ -327,7 +331,9 @@ public:
 
     void do_continue (const UString &a_cookie);
 
-    void run (const UString &a_cookie) ;
+    void run (const UString &a_cookie);
+
+    void re_run (const DefaultSlot &);
 
     void get_target_info (const UString &a_cookie);
 
@@ -337,6 +343,8 @@ public:
 
     bool is_variable_editable (const VariableSafePtr) const;
 
+    bool is_running () const;
+
     IDebugger::State get_state () const;
 
     int get_current_frame_level () const;
