@@ -366,7 +366,7 @@ public:
         FrameArgsSlot;
 
     typedef sigc::slot<void, const VariableSafePtr> ConstVariableSlot;
-    typedef sigc::slot<void, const VariableList> ConstVariableListSlot;
+    typedef sigc::slot<void, const VariableList&> ConstVariableListSlot;
     typedef sigc::slot<void, const UString&> ConstUStringSlot;
 
     class Variable : public Object {
@@ -431,12 +431,12 @@ public:
         bool m_has_more_children;
 
     public:
-        Variable (const UString &a_internal_name,
-                  const UString &a_name,
-                  const UString &a_value,
-                  const UString &a_type,
-                  bool a_in_scope = true,
-                  IDebugger *a_dbg = 0)
+        explicit Variable (const UString &a_internal_name,
+                           const UString &a_name,
+                           const UString &a_value,
+                           const UString &a_type,
+                           bool a_in_scope = true,
+                           IDebugger *a_dbg = 0)
             : m_internal_name (a_internal_name),
             m_debugger (a_dbg),
             m_name (a_name),
@@ -452,10 +452,10 @@ public:
         {
         }
 
-        Variable (const UString &a_name,
-                  const UString &a_value,
-                  const UString &a_type,
-                  bool a_in_scope = true,
+        explicit Variable (const UString &a_name,
+                           const UString &a_value,
+                           const UString &a_type,
+                           bool a_in_scope = true,
                   IDebugger *a_dbg = 0)
             : m_debugger (a_dbg),
             m_name (a_name),
@@ -472,8 +472,8 @@ public:
         {
         }
 
-        Variable (const UString &a_name,
-                  IDebugger *a_dbg = 0)
+        explicit Variable (const UString &a_name,
+                           IDebugger *a_dbg = 0)
             : m_debugger (a_dbg),
             m_name (a_name),
             m_parent (0),
@@ -558,7 +558,7 @@ public:
             THROW ("fatal: should not be reached");
         }
 
-        bool operator == (const Variable &a_other) const
+        bool operator== (const Variable &a_other) const
         {
             return equals (a_other);
         }
@@ -622,6 +622,14 @@ public:
         /// \param a_in the new name of backend side counterpart variable object.
         void internal_name (const UString &a_in) {m_internal_name = a_in;}
 
+        /// Return the ID of the variable.  The ID is either the
+        /// internal_name of the variable if it has one, or its user
+        /// facing name.
+        const UString& id () const
+        { return internal_name ().empty ()
+                ? name ()
+                : internal_name ();
+        }
 
         IDebugger* debugger () const {return m_debugger;}
         void debugger (IDebugger *a_dbg) {m_debugger = a_dbg;}
@@ -656,6 +664,28 @@ public:
             return m_parent != 0;
         }
 
+        /// If this variable has a backend counterpart (e.g GDB
+        /// Backend variable object) then, there are cases where a
+        /// variable sub-object can be returned by the backend without
+        /// being linked to its ancestor tree.  Such a variable
+        /// appears as being structurally root (it has no parent), but
+        /// is morally a sub-variable.  A variable that is
+        /// structurally non-root is also morally non-root.
+        ///
+        /// To know if a variable is morally root, this function
+        /// detects if the fully qualified internal name of the
+        /// variable has dot (".") in it (e.g, "variable.member").  If
+        /// does not, then the function assumes the variable is
+        /// morally root and returns true.
+        bool is_morally_root () const
+        {
+            if (has_parent ())
+                return false;
+            if (internal_name ().empty ())
+                return !has_parent ();
+            return (internal_name ().find (".") == UString::npos);
+        }
+
         /// A getter of the parent Variable of the current instance.
         const VariableSafePtr parent () const
         {
@@ -903,9 +933,16 @@ public:
     };//end class Variable
 
     enum State {
+        // The inferior hasn't been loaded.
         NOT_STARTED=0,
+        // The inferior has been loaded, but hasn't been run yet.
+        INFERIOR_LOADED,
+        // The inferior has started its execution, but is currently
+        // stopped.
         READY,
+        // The inferior is currently busy running.
         RUNNING,
+        // The inferior has exited.
         PROGRAM_EXITED
     };//enum State
 
@@ -913,18 +950,21 @@ public:
     {
         UString str;
         switch (a_state) {
-            case NOT_STARTED:
-                str = "NOT_STARTED";
-                break;
-            case READY:
-                str = "READY";
-                break;
-            case RUNNING:
-                str = "RUNNING";
-                break;
-            case PROGRAM_EXITED:
-                str = "PROGRAM_EXITED";
-                break;
+        case NOT_STARTED:
+            str = "NOT_STARTED";
+            break;
+        case INFERIOR_LOADED:
+            str = "INFERIOR_LOADED";
+            break;
+        case READY:
+            str = "READY";
+            break;
+        case RUNNING:
+            str = "RUNNING";
+            break;
+        case PROGRAM_EXITED:
+            str = "PROGRAM_EXITED";
+            break;
         }
         return str;
     }
@@ -992,6 +1032,10 @@ public:
 
     virtual sigc::signal<void>& detached_from_target_signal () const=0;
 
+    /// Signal emitted whenever the inferior is re-run, using the
+    /// function IDebugger::re_run.
+    virtual sigc::signal<void>& inferior_re_run_signal () const = 0;
+
     virtual sigc::signal<void,
                         const IDebugger::Breakpoint&,
                         int /*breakpoint command*/,
@@ -1183,6 +1227,12 @@ public:
     virtual sigc::signal<void, const VariableSafePtr, const UString&>&
                                  variable_expression_evaluated_signal () const = 0;
 
+    /// This is a callback slot invoked upon completion of the
+    /// IDebugger::list_changed_variables entry point.
+    ///
+    /// The parameters of the slots are the list of variables
+    /// that changed, and the cookie passed to
+    /// IDebugger::list_changed_variables.
     virtual sigc::signal<void, const VariableList&, const UString&>&
                                 changed_variables_signal () const  = 0;
 
@@ -1223,7 +1273,9 @@ public:
                  const vector<UString> &a_argv,
                  const UString &working_dir,
                  const vector<UString> &a_source_search_dirs,
-                 const UString &a_tty_path,
+                 const UString &a_slave_tty_path,
+                 int a_slave_tty_fd,
+                 bool a_uses_launch_tty = false,
                  bool a_force = false) = 0;
 
     virtual void load_core_file (const UString &a_prog_file,
@@ -1257,10 +1309,14 @@ public:
 
     virtual bool is_variable_editable (const VariableSafePtr a_var) const = 0;
 
+    virtual bool is_running () const = 0;
+
     virtual void do_continue (const UString &a_cookie="") = 0;
 
     virtual void run (const UString &a_cookie="") = 0;
 
+    virtual void re_run (const DefaultSlot &) = 0;
+
     virtual IDebugger::State get_state () const = 0;
 
     virtual int get_current_frame_level () const = 0;
@@ -1565,8 +1621,28 @@ public:
              const ConstVariableSlot &a_slot,
              const UString &a_cookie = "")= 0;
 
+    /// List the sub-variables of a_root (including a_root)
+    /// which value changed since the last time this function was
+    /// invoked.
+    ///
+    /// \param a_root the variable to consider
+    ///
+    /// \param a_cookie the cookie to be passed to the callback
+    //// slot IDebugger::changed_variables_signal
     virtual void list_changed_variables (VariableSafePtr a_root,
                                          const UString &a_cookie = "") = 0;
+
+    /// List the sub-variables of a_root (including a_root) which value
+    /// changed since the last time this function was called.
+    ///
+    /// \param a_root the variable to consider
+    /// 
+    /// \param a_slot the slot to be invoked upon completion of this
+    /// function.  That slot is going to be passed the list of
+    /// sub-variables that have changed.
+    /// 
+    /// \a_cookie the cookie to be passed to the callback function
+    /// IDebugger::changed_variables_signal
     virtual void list_changed_variables
             (VariableSafePtr a_root,
              const ConstVariableListSlot &a_slot,
