@@ -231,6 +231,8 @@ public:
         tree_view->signal_row_activated ().connect
             (sigc::mem_fun (*this,
                             &Priv::on_tree_view_row_activated_signal));
+        // Schedule the button press signal handler to be run before
+        // the default handler.
         tree_view->signal_button_press_event ().connect_notify
             (sigc::mem_fun (this, &Priv::on_button_press_signal));
         tree_view->signal_draw ().connect_notify
@@ -253,7 +255,7 @@ public:
             {
                 "CopyLocalVariablePathMenuItemAction",
                 Gtk::Stock::COPY,
-                _("_Copy variable name"),
+                _("_Copy Variable Name"),
                 _("Copy the variable path expression to the clipboard"),
                 sigc::mem_fun
                     (*this,
@@ -265,7 +267,7 @@ public:
             {
                 "CopyVariableValueMenuItemAction",
                 Gtk::Stock::COPY,
-                _("_Copy variable value"),
+                _("_Copy Variable Value"),
                 _("Copy the variable value to the clipboard"),
                 sigc::mem_fun
                     (*this,
@@ -277,7 +279,7 @@ public:
             {
                 "CreateWatchpointMenuItemAction",
                 Gtk::Stock::COPY,
-                _("Create watchpoint"),
+                _("Create Watchpoint"),
                 _("Create a watchpoint that triggers when the value "
                   "of the expression changes"),
                 sigc::mem_fun
@@ -974,7 +976,7 @@ public:
         NEMIVER_TRY
 
         std::string str;
-        dutil::dump_variable_value (a_var, 0, str);
+        dutil::dump_variable_value (*a_var, 0, str);
 
         if (!str.empty ())
             Gtk::Clipboard::get ()->set_text (str);
@@ -1170,7 +1172,7 @@ public:
         THROW_IF_FAIL (variable);
 
         IVarWalkerSafePtr walker = get_varobj_walker ();
-        walker->connect (debugger, variable);
+        walker->connect (debugger.get (), variable);
         walker->do_walk_variable ();
 
         NEMIVER_CATCH
