@@ -170,21 +170,21 @@ struct Terminal::Priv {
         action_group->add (Gtk::Action::create
                 ("CopyAction",
                  Gtk::Stock::COPY,
-                 "_Copy",
+                 _("_Copy"),
                  _("Copy the selection")),
                  sigc::mem_fun (*this,
                                 &Terminal::Priv::on_copy_signal));
         action_group->add (Gtk::Action::create
                 ("PasteAction",
                  Gtk::Stock::PASTE,
-                 "_Paste",
+                 _("_Paste"),
                  _("Paste the clipboard")),
                  sigc::mem_fun (*this,
                                 &Terminal::Priv::on_paste_signal));
         action_group->add (Gtk::Action::create
                 ("ResetAction",
                  Gtk::StockID (""),
-                 "_Reset",
+                 _("_Reset"),
                  _("Reset the terminal")),
                  sigc::mem_fun (*this,
                                 &Terminal::Priv::on_reset_signal));
@@ -263,16 +263,6 @@ struct Terminal::Priv {
         THROW_IF_FAIL (slave_pty);
         THROW_IF_FAIL (master_pty);
 
-        if (grantpt (master_pty)) {
-            LOG_ERROR ("oops");
-            return false;
-        }
-
-        if (unlockpt (master_pty)) {
-            LOG_ERROR ("oops");
-            return false;
-        }
-
         vte_terminal_set_pty (vte, master_pty);
         return true;
     }
@@ -305,18 +295,28 @@ Terminal::adjustment () const
     return m_priv->adjustment;
 }
 
+/// Return the file descriptor of the slave pseudo tty used by the the
+/// proces that would want to communicate with this terminal.
+int
+Terminal::slave_pty () const
+{
+    THROW_IF_FAIL (m_priv);
+    THROW_IF_FAIL (m_priv->slave_pty);
+    return m_priv->slave_pty;
+}
+
 UString
 Terminal::slave_pts_name () const
 {
     THROW_IF_FAIL (m_priv);
     UString result;
 
-    if (!m_priv->master_pty) {
+    if (!m_priv->slave_pty) {
         LOG_ERROR ("oops");
         return result;
     }
 
-    result = ptsname (m_priv->master_pty);
+    result = ttyname (m_priv->slave_pty);
     return result;
 }
 
