@@ -233,21 +233,9 @@ Workbench::on_quit_menu_item_action ()
 void
 Workbench::on_contents_menu_item_action ()
 {
-    NEMIVER_TRY
-
-    UString help_url = "ghelp:nemiver";
+    UString help_url = "help:" PACKAGE_TARNAME;
     LOG_DD ("launching help url: " << help_url);
-    UString path_to_help =
-        nemiver::common::env::build_path_to_help_file ("nemiver.xml");
-    THROW_IF_FAIL (!path_to_help.empty ());
-    UString cmd_line ("yelp " + path_to_help);
-    LOG_DD ("going to spawn: " << cmd_line);
-    bool is_ok = g_spawn_command_line_async (Glib::locale_from_utf8
-                                             (cmd_line).c_str (), 0);
-    if (!is_ok) {
-        LOG_ERROR ("failed to spawn " << is_ok);
-    }
-    NEMIVER_CATCH
+    gtk_show_uri (NULL, help_url.c_str (), 0, NULL);
 }
 
 void
@@ -587,7 +575,7 @@ Workbench::init_builder ()
 
     Gtk::Widget *w =
         ui_utils::get_widget_from_gtkbuilder<Gtk::Window> (m_priv->builder,
-                                                      "workbench");
+                                                           "workbench");
     THROW_IF_FAIL (w);
     m_priv->root_window.reset (dynamic_cast<Gtk::Window*>
                                                 (w->get_toplevel ()));
@@ -736,11 +724,12 @@ Workbench::init_actions ()
 
     m_priv->default_action_group =
         Gtk::ActionGroup::create ("workbench-default-action-group");
-    int num_default_actions =
-         sizeof (s_default_action_entries)/sizeof (ui_utils::ActionEntry);
-    ui_utils::add_action_entries_to_action_group (s_default_action_entries,
-                                                  num_default_actions,
-                                                  m_priv->default_action_group);
+
+       ui_utils::add_action_entries_to_action_group
+           (s_default_action_entries,
+            G_N_ELEMENTS (s_default_action_entries),
+            m_priv->default_action_group);
+
     get_ui_manager ()->insert_action_group (m_priv->default_action_group);
 }
 
@@ -771,7 +760,8 @@ Workbench::init_toolbar ()
 
     m_priv->toolbar_container =
         ui_utils::get_widget_from_gtkbuilder<Gtk::Notebook> (m_priv->builder,
-                                                        "toolbarcontainer");
+                                                             "toolbarcontainer");
+    m_priv->toolbar_container->show_all ();
 }
 
 void
@@ -780,7 +770,8 @@ Workbench::init_body ()
     LOG_FUNCTION_SCOPE_NORMAL_DD;
     m_priv->bodies_container =
         ui_utils::get_widget_from_gtkbuilder<Gtk::Notebook> (m_priv->builder,
-                                                        "bodynotebook");
+                                                             "bodynotebook");
+    m_priv->bodies_container->show_all ();
 }
 
 void
@@ -813,6 +804,8 @@ Workbench::add_perspective_body (IPerspectiveSafePtr &a_perspective,
 
     if (!a_body || !a_perspective) {return;}
 
+    a_body->show_all ();
+
     m_priv->bodies_index_map[a_perspective.get ()] =
         m_priv->bodies_container->insert_page (*a_body, -1);
 }
@@ -823,6 +816,8 @@ Workbench::on_perspective_layout_changed_signal
 {
     LOG_FUNCTION_SCOPE_NORMAL_DD;
 
+    NEMIVER_TRY;
+
     THROW_IF_FAIL (m_priv);
     THROW_IF_FAIL (m_priv->bodies_container);
 
@@ -831,9 +826,15 @@ Workbench::on_perspective_layout_changed_signal
     int page = m_priv->bodies_index_map[a_perspective.get ()];
 
     m_priv->bodies_container->remove_page (page);
-    m_priv->bodies_container->insert_page (*a_perspective->get_body (), page);
+
+    Gtk::Widget *b = a_perspective->get_body ();
+    THROW_IF_FAIL (b);
+    b->show_all ();
+    m_priv->bodies_container->insert_page (*b, page);
 
     select_perspective (a_perspective);
+
+    NEMIVER_CATCH;
 }
 
 bool
